@@ -12,5 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from .email_verify import handle_email_verify_api  # type: ignore
-from .generate_email_verify_token import \
-    handle_generate_email_verify_token_api  # type: ignore
+from .generate_email_verify_token import (
+    handle_generate_email_verify_token_api,  # type: ignore
+)
