@@ -13,29 +13,46 @@
 # under the License.
 from typing import Any, Dict, Union
 
-from supertokens_python.recipe.openid.interfaces import \
-    GetOpenIdDiscoveryConfigurationResult
+from supertokens_python.recipe.openid.interfaces import (
+    GetOpenIdDiscoveryConfigurationResult,
+)
 from supertokens_python.recipe.openid.recipe import OpenIdRecipe
 
-from ...jwt.interfaces import CreateJwtOkResult, CreateJwtResultUnsupportedAlgorithm, GetJWKSResult
+from ...jwt.interfaces import (
+    CreateJwtOkResult,
+    CreateJwtResultUnsupportedAlgorithm,
+    GetJWKSResult,
+)
 
 
-async def create_jwt(payload: Union[None, Dict[str, Any]] = None, validity_seconds: Union[None, int] = None, user_context: Union[Dict[str, Any], None] = None) -> Union[CreateJwtOkResult, CreateJwtResultUnsupportedAlgorithm]:
+async def create_jwt(
+    payload: Union[None, Dict[str, Any]] = None,
+    validity_seconds: Union[None, int] = None,
+    user_context: Union[Dict[str, Any], None] = None,
+) -> Union[CreateJwtOkResult, CreateJwtResultUnsupportedAlgorithm]:
     if user_context is None:
         user_context = {}
     if payload is None:
         payload = {}
 
-    return await OpenIdRecipe.get_instance().recipe_implementation.create_jwt(payload, validity_seconds, user_context)
+    return await OpenIdRecipe.get_instance().recipe_implementation.create_jwt(
+        payload, validity_seconds, user_context
+    )
 
 
 async def get_jwks(user_context: Union[Dict[str, Any], None] = None) -> GetJWKSResult:
     if user_context is None:
         user_context = {}
-    return await OpenIdRecipe.get_instance().recipe_implementation.get_jwks(user_context)
+    return await OpenIdRecipe.get_instance().recipe_implementation.get_jwks(
+        user_context
+    )
 
 
-async def get_open_id_discovery_configuration(user_context: Union[Dict[str, Any], None] = None) -> GetOpenIdDiscoveryConfigurationResult:
+async def get_open_id_discovery_configuration(
+    user_context: Union[Dict[str, Any], None] = None
+) -> GetOpenIdDiscoveryConfigurationResult:
     if user_context is None:
         user_context = {}
-    return await OpenIdRecipe.get_instance().recipe_implementation.get_open_id_discovery_configuration(user_context)
+    return await OpenIdRecipe.get_instance().recipe_implementation.get_open_id_discovery_configuration(
+        user_context
+    )
