@@ -21,15 +21,18 @@ from typing import Any, Awaitable, Callable, Dict, Union
 from httpx import AsyncClient, HTTPStatusError
 from supertokens_python.ingredients.emaildelivery import EmailDeliveryInterface
 from supertokens_python.logger import log_debug_message
-from supertokens_python.recipe.passwordless.types import \
-    PasswordlessLoginEmailTemplateVars
+from supertokens_python.recipe.passwordless.types import (
+    PasswordlessLoginEmailTemplateVars,
+)
 from supertokens_python.supertokens import AppInfo
 from supertokens_python.utils import handle_httpx_client_exceptions
 
 
-def default_create_and_send_custom_email(app_info: AppInfo) -> Callable[[PasswordlessLoginEmailTemplateVars, Dict[str, Any]], Awaitable[None]]:
+def default_create_and_send_custom_email(
+    app_info: AppInfo,
+) -> Callable[[PasswordlessLoginEmailTemplateVars, Dict[str, Any]], Awaitable[None]]:
     async def func(input_: PasswordlessLoginEmailTemplateVars, _: Dict[str, Any]):
-        if ('SUPERTOKENS_ENV' in environ) and (environ['SUPERTOKENS_ENV'] == 'testing'):
+        if ("SUPERTOKENS_ENV" in environ) and (environ["SUPERTOKENS_ENV"] == "testing"):
             return
         data = {
             "email": input_.email,
@@ -37,12 +40,12 @@ def default_create_and_send_custom_email(app_info: AppInfo) -> Callable[[Passwor
             "codeLifetime": input_.code_life_time,
         }
         if input_.url_with_link_code:
-            data['urlWithLinkCode'] = input_.url_with_link_code
+            data["urlWithLinkCode"] = input_.url_with_link_code
         if input_.user_input_code:
-            data['userInputCode'] = input_.user_input_code
+            data["userInputCode"] = input_.user_input_code
         try:
             async with AsyncClient() as client:
-                resp = await client.post('https://api.supertokens.io/0/st/auth/passwordless/login', json=data, headers={'api-version': '0'})  # type: ignore
+                resp = await client.post("https://api.supertokens.io/0/st/auth/passwordless/login", json=data, headers={"api-version": "0"})  # type: ignore
                 resp.raise_for_status()
                 log_debug_message("Passwordless login email sent to %s", input_.email)
         except Exception as e:
@@ -63,15 +66,30 @@ def default_create_and_send_custom_email(app_info: AppInfo) -> Callable[[Passwor
     return func
 
 
-class BackwardCompatibilityService(EmailDeliveryInterface[PasswordlessLoginEmailTemplateVars]):
-    def __init__(self,
-                 app_info: AppInfo,
-                 create_and_send_custom_email: Union[
-                     Callable[[PasswordlessLoginEmailTemplateVars, Dict[str, Any]], Awaitable[None]],
-                     None
-                 ] = None
-                 ) -> None:
-        self.create_and_send_custom_email = create_and_send_custom_email if create_and_send_custom_email is not None else default_create_and_send_custom_email(app_info)
+class BackwardCompatibilityService(
+    EmailDeliveryInterface[PasswordlessLoginEmailTemplateVars]
+):
+    def __init__(
+        self,
+        app_info: AppInfo,
+        create_and_send_custom_email: Union[
+            Callable[
+                [PasswordlessLoginEmailTemplateVars, Dict[str, Any]], Awaitable[None]
+            ],
+            None,
+        ] = None,
+    ) -> None:
+        self.create_and_send_custom_email = (
+            create_and_send_custom_email
+            if create_and_send_custom_email is not None
+            else default_create_and_send_custom_email(app_info)
+        )
 
-    async def send_email(self, template_vars: PasswordlessLoginEmailTemplateVars, user_context: Dict[str, Any]) -> None:
-        await self.create_and_send_custom_email(template_vars, user_context)  # Note: intentionally not using try-except (unlike other recipes)
+    async def send_email(
+        self,
+        template_vars: PasswordlessLoginEmailTemplateVars,
+        user_context: Dict[str, Any],
+    ) -> None:
+        await self.create_and_send_custom_email(
+            template_vars, user_context
+        )  # Note: intentionally not using try-except (unlike other recipes)
