@@ -31,26 +31,29 @@ from supertokens_python.ingredients.emaildelivery.types import (
     SMTPSettings,
     SMTPSettingsFrom,
 )
-from supertokens_python.recipe import session, thirdparty
+from supertokens_python.recipe import session, thirdparty, emailverification
 from supertokens_python.recipe.session import SessionRecipe
 from supertokens_python.recipe.session.recipe_implementation import (
     RecipeImplementation as SessionRecipeImplementation,
 )
 from supertokens_python.recipe.session.session_functions import create_new_session
 from supertokens_python.recipe.thirdparty.asyncio import sign_in_up
-from supertokens_python.recipe.thirdparty.emaildelivery.services.smtp import SMTPService
+from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import (
+    SMTPService,
+)
 from supertokens_python.recipe.thirdparty.interfaces import SignInUpOkResult
 from supertokens_python.recipe.thirdparty.provider import Provider
 from supertokens_python.recipe.thirdparty.types import (
     AccessTokenAPI,
     AuthorisationRedirectAPI,
-    EmailTemplateVars,
-    User,
     UserInfo,
     UserInfoEmail,
-    VerificationEmailTemplateVars,
 )
 from tests.utils import clean_st, email_verify_token_request, reset, setup_st, start_st
+from supertokens_python.recipe.emailverification.types import (
+    User as EVUser,
+    VerificationEmailTemplateVars,
+)
 
 respx_mock = respx.MockRouter
 
@@ -128,6 +131,7 @@ async def test_email_verify_default_backward_compatibility(
         ),
         framework="fastapi",
         recipe_list=[
+            emailverification.init(mode="OPTIONAL"),
             thirdparty.init(
                 sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
                     providers=[CustomProvider("CUSTOM", True)]
@@ -138,7 +142,7 @@ async def test_email_verify_default_backward_compatibility(
     )
     start_st()
 
-    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com", False)
+    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com")
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -198,6 +202,7 @@ async def test_email_verify_default_backward_compatibility_supress_error(
         ),
         framework="fastapi",
         recipe_list=[
+            emailverification.init(mode="OPTIONAL"),
             thirdparty.init(
                 sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
                     providers=[CustomProvider("CUSTOM", True)]
@@ -208,7 +213,7 @@ async def test_email_verify_default_backward_compatibility_supress_error(
     )
     start_st()
 
-    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com", False)
+    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com")
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -257,7 +262,7 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
     email_verify_url = ""
 
     async def create_and_send_custom_email(
-        input_: User, email_verification_link: str, _: Dict[str, Any]
+        input_: EVUser, email_verification_link: str, _: Dict[str, Any]
     ):
         nonlocal email, email_verify_url
         email = input_.email
@@ -273,20 +278,21 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
         ),
         framework="fastapi",
         recipe_list=[
+            emailverification.init(
+                mode="OPTIONAL",
+                create_and_send_custom_email=create_and_send_custom_email,
+            ),
             thirdparty.init(
                 sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
                     providers=[CustomProvider("CUSTOM", True)]
-                ),
-                email_verification_feature=thirdparty.InputEmailVerificationConfig(
-                    create_and_send_custom_email=create_and_send_custom_email,
-                ),
+                )
             ),
             session.init(),
         ],
     )
     start_st()
 
-    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com", False)
+    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com")
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -317,11 +323,13 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
     email = ""
     email_verify_url = ""
 
-    def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]):
+    def email_delivery_override(
+        oi: EmailDeliveryInterface[VerificationEmailTemplateVars],
+    ):
         oi_send_email = oi.send_email
 
         async def send_email(
-            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+            template_vars: VerificationEmailTemplateVars, user_context: Dict[str, Any]
         ):
             nonlocal email, email_verify_url
             assert isinstance(template_vars, VerificationEmailTemplateVars)
@@ -342,21 +350,24 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
         ),
         framework="fastapi",
         recipe_list=[
-            thirdparty.init(
-                sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
-                    providers=[CustomProvider("CUSTOM", True)]
-                ),
+            emailverification.init(
+                mode="OPTIONAL",
                 email_delivery=EmailDeliveryConfig(
                     service=None,
                     override=email_delivery_override,
                 ),
             ),
+            thirdparty.init(
+                sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
+                    providers=[CustomProvider("CUSTOM", True)]
+                ),
+            ),
             session.init(),
         ],
     )
     start_st()
 
-    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com", False)
+    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com")
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -406,7 +417,7 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
         False,
     )
 
-    def smtp_service_override(oi: SMTPServiceInterface[EmailTemplateVars]):
+    def smtp_service_override(oi: SMTPServiceInterface[VerificationEmailTemplateVars]):
         async def send_raw_email_override(
             content: EmailContent, _user_context: Dict[str, Any]
         ):
@@ -420,7 +431,7 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
             # Note that we aren't calling oi.send_raw_email. So Transporter won't be used.
 
         async def get_content_override(
-            template_vars: EmailTemplateVars, _user_context: Dict[str, Any]
+            template_vars: VerificationEmailTemplateVars, _user_context: Dict[str, Any]
         ) -> EmailContent:
             nonlocal get_content_called, email_verify_url
             get_content_called = True
@@ -452,12 +463,12 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
     )
 
     def email_delivery_override(
-        oi: EmailDeliveryInterface[EmailTemplateVars],
-    ) -> EmailDeliveryInterface[EmailTemplateVars]:
+        oi: EmailDeliveryInterface[VerificationEmailTemplateVars],
+    ) -> EmailDeliveryInterface[VerificationEmailTemplateVars]:
         oi_send_email = oi.send_email
 
         async def send_email_override(
-            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+            template_vars: VerificationEmailTemplateVars, user_context: Dict[str, Any]
         ):
             nonlocal outer_override_called
             outer_override_called = True
@@ -476,21 +487,24 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
         ),
         framework="fastapi",
         recipe_list=[
-            thirdparty.init(
-                sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
-                    providers=[CustomProvider("CUSTOM", True)]
-                ),
+            emailverification.init(
+                mode="OPTIONAL",
                 email_delivery=EmailDeliveryConfig(
                     service=email_delivery_service,
                     override=email_delivery_override,
                 ),
             ),
+            thirdparty.init(
+                sign_in_and_up_feature=thirdparty.SignInAndUpFeature(
+                    providers=[CustomProvider("CUSTOM", True)]
+                ),
+            ),
             session.init(),
         ],
     )
     start_st()
 
-    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com", False)
+    resp = await sign_in_up("supertokens", "test-user-id", "test@example.com")
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
